import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

void main() {
  return runApp(_ChartApp());
}

class _ChartApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      theme: ThemeData(primarySwatch: Colors.blue),
      home: _MyHomePage(),
    );
  }
}

class _MyHomePage extends StatefulWidget {
  // ignore: prefer_const_constructors_in_immutables
  _MyHomePage({Key? key}) : super(key: key);

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<_MyHomePage> {
  List<_SalesData> data1 = [
    _SalesData('2021\nQ1', 35),
    _SalesData('2021\nQ2', 28),
    _SalesData('2021\nQ3', 34),
    _SalesData('2021\nQ4', 32),
    _SalesData('2022\nQ1', 40),
    _SalesData('2022\nQ2', 30),
    _SalesData('2022\nQ3', 40),
  ];

  List<_SalesData> forcastSales1Data = [
    _SalesData('2022\nQ2', 30),
    _SalesData('2022\nQ3', 40),
    _SalesData('2022\nQ4', 30),
  ];

  // Create a boolean for forcast series visibility
  late bool forcastSales1Visibility;

  @override
  void initState() {
    /// Defaults to 'true'
    forcastSales1Visibility = true;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Syncfusion Flutter chart'),
        ),
        body: Column(children: [
          //Initialize the chart widget
          SfCartesianChart(
              primaryXAxis: CategoryAxis(
                labelPlacement: LabelPlacement.onTicks,
              ),
              legend: Legend(isVisible: true, position: LegendPosition.bottom),
              onLegendTapped: (args) {
                /// In the addPostFrameCallback, set the visibility based on the main series legend toggle. 
                /// here's when toggling the first series, the respective forcast series will get hidden.
                SchedulerBinding.instance.addPostFrameCallback((_) {
                  setState(() {
                  if (args.seriesIndex == 0) {
                    forcastSales1Visibility = !forcastSales1Visibility;
                  }
                });
                });
                
              },
              series: <ChartSeries<_SalesData, String>>[
                AreaSeries<_SalesData, String>(
                    dataSource: data1,
                    xValueMapper: (_SalesData sales, _) => sales.year,
                    yValueMapper: (_SalesData sales, _) => sales.sales,
                    color: Colors.blue,
                    name: 'Sales1'),
                AreaSeries<_SalesData, String>(
                    dataSource: forcastSales1Data,
                    isVisible: forcastSales1Visibility,
                    opacity: 0.5,
                    color: Colors.blue,
                    isVisibleInLegend: false,
                    xValueMapper: (_SalesData sales, _) => sales.year,
                    yValueMapper: (_SalesData sales, _) => sales.sales,
                    name: 'ForcastSales1'),
              ]),
        ]));
  }
}

class _SalesData {
  _SalesData(this.year, this.sales);

  final String year;
  final double sales;
}
